California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 032 - PROHIBITS POLITICAL CONTRIBUTIONS BY PAYROLL DEDUCTIONS. PROHIBITIONS ON CONTRIBUTIONS TO CANDIDATES. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1337891 | CALIFORNIANS AGAINST SPECIAL INTERESTS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1350977 | SOUTHERN CALIFORNIA ALLIANCE OF LAW ENFORCEMENT COMMITTEE TO OPPOSE PROPOSITIONS 32 AND 34 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1350885 | MI FAMILIA VOTA - YES ON 30 AND 39 FOR TAX FAIRNESS AND NO ON 32 TO STOP SPECIAL EXEMPTIONS FOR CORPORATE POLITICAL SPENDING, SPONSORED BY THE CALIFORNIA STATE COUNCIL OF SERVICE EMPLOYEES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270683 | SMALL BUSINESS ACTION COMMITTEE PAC, NO ON 30/YES ON 32, CITIZENS FOR REFORMING SACRAMENTO | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322497 | CITIZEN POWER CAMPAIGN | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1340076 | NO ON 32, STOP CORPORATE SPECIAL EXEMPTIONS FROM CAMPAIGN FINANCE RULES, SPONSORED BY WORKING FAMILIES AND LABOR ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
941597 | CALIFORNIA NURSES ASSOCIATION INITIATIVE POLITICAL ACTION COMMITTEE (YES ON 30 AND NO ON 32) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346267 | CALIFORNIA STATEWIDE LAW ENFORCEMENT ASSOCIATION ISSUES COMMITTEE, YES ON PROPOSITIONS 30 AND 35, NO ON PROPOSITION 32 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1351572 | CALIFORNIA FUTURE FUND FOR FREE MARKETS YES ON PROPOSITION 32 WITH MAJOR FUNDING BY AMERICAN FUTURE FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | CALIFORNIANS FOR INFORMED VOTING - YES ON 30, 34, 35, 36, 37, AND 39 AND NO ON 31 AND 32 SPONSORED BY BALLOT INITIATIVE STRATEGY CENTER | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1289844 | WORKING CALIFORNIANS TO OPPOSE PROP. 32, A COALITION OF LABOR ORGANIZATIONS, WORKING MEN & WOMEN | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
890947 | SHEET METAL WORKERS' INTERNATIONAL ASSOCIATION POLITICAL ACTION COMMITTEE, YES ON 30 AND NO ON 32 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343790 | YES ON 32 - STOP SPECIAL INTEREST MONEY NOW. SUPPORTED BY SMALL BUSINESS OWNERS, FARMERS, EDUCATORS, AND TAXPAYERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1347688 | RECLAIM CALIFORNIA'S FUTURE - YES ON PROP. 30, NO ON PROP. 32 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1347975 | INTERNATIONAL ASSOCIATION OF FIRE FIGHTERS OPPOSED TO THE SPECIAL EXEMPTIONS ACT NO ON MEASURE 32 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1336580 | LOS ANGELES POLICE PROTECTIVE LEAGUE'S (LAPPL) PUBLIC SAFETY FIRST POLITICAL ACTION COMMITTEE - NO ON 32 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1351941 | UNITED FOOD AND COMMERCIAL WORKERS ACTIVE BALLOT CLUB YES ON PROP. 30, NO ON PROP. 32 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348981 | STUDENTS AND FAMILIES OF CALIFORNIA, YES ON 30/NO ON 32 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348995 | ASIAN PACIFIC ENVIRONMENTAL NETWORK (APEN) ACTION'S YES ON 30 & 39, NO ON 32 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1349099 | YES ON 30 TO SAVE OUR SCHOOLS & NO ON 32 TO STOP CAMPAIGN FINANCE LOOPHOLES FOR CORPORATE INTERESTS, SPONSORED BY GOOD JOBS SAFE COMMUNITIES LA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344800 | CALIFORNIA CALLS ACTION FUND: A COALITION OF SOCIAL JUSTICE ORGANIZATIONS FOR PROP. 30 AND AGAINST PROP. 32 | OPPOSE